==> blobAndConquer-0.5-1.tar.gz: blobAndConquer-0.5/src/missions/mission.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern List *loadProperties(char *filename, bool fromPak);
extern void loadAllMapData(char *setname);
extern void generateMap(int width, int height);
extern bool allEnemyUnitsDead();
extern bool enemyPositonOK(Unit *enemy);
extern bool isBasePlateSquare(Vector position);
extern void placePlayerUnits();
extern void placeEnemyUnits();
extern void addFeature(Properties *props);
extern void addBlob(Properties *props);
extern Item *addItem(Properties *props);
extern Weapon *addWeapon(Properties *props);
extern void addDoor(Properties *props);
extern void addTrigger(Properties *props);
extern void loadBSP(char *filename);
extern List *loadBSPProperties(char *entities);
extern void addEnemy(Properties *props);
extern void spawnBob();
extern void addStructure(Properties *props);
extern void addSwitch(Properties *props);
extern void addSpecialSwitch(Properties *props);
extern void addWindow(Properties *props);
extern void addEnergyBarrier(Properties *props);
extern void addLift(Properties *props);
extern void addWeakWall(Properties *props);
extern void addPressurePlate(Properties *props);
extern void addDemolitionPlate(Properties *props);
extern void addPushBlock(Properties *props);
extern void addAutoLift(Properties *props);
extern void addCustomItem(Properties *props);
extern void reassignOwnerShips();
extern void removeBSPModelFaces();
extern void addBullet(Properties *props);
extern void addParticle(Properties *props);
extern void addDecoration(Properties *props);
extern bool loadGameData(int slotId, char *mission);
extern void fireTriggers(char *name, int type);
extern void addCutsceneCamera(Properties *props);
extern void addEmitter(Properties *props);
extern void addWeakStructure(Properties *props);
extern void addTrap(Properties *props);
extern void addLocation(Properties *props);
extern void addDecal(Properties *props);
extern void assignTriggerLocations();
extern void addSupplyCrate(Properties *props);
extern void addBoss(Properties *props);

extern Audio *audio;
extern BSP *bsp;
extern EntityManager *entityManager;
extern Engine *engine;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern RandomNameGenerator *randomNameGenerator;
extern TextureManager *textureManager;

extern Unit *player;

==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/missions/mission.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern List *loadProperties(char *filename, bool fromPak);
extern void loadAllMapData(char *setname);
extern void generateMap(int width, int height);
extern bool allEnemyUnitsDead();
extern bool enemyPositonOK(Unit *enemy);
extern bool isBasePlateSquare(Vector position);
extern void placePlayerUnits();
extern void placeEnemyUnits();
extern void addFeature(Properties *props);
extern void addBlob(Properties *props);
extern Item *addItem(Properties *props);
extern Weapon *addWeapon(Properties *props);
extern void addDoor(Properties *props);
extern void addTrigger(Properties *props);
extern void loadBSP(char *filename);
extern List *loadBSPProperties(char *entities);
extern void addEnemy(Properties *props);
extern void spawnBob();
extern void addStructure(Properties *props);
extern void addSwitch(Properties *props);
extern void addSpecialSwitch(Properties *props);
extern void addWindow(Properties *props);
extern void addEnergyBarrier(Properties *props);
extern void addLift(Properties *props);
extern void addWeakWall(Properties *props);
extern void addPressurePlate(Properties *props);
extern void addDemolitionPlate(Properties *props);
extern void addPushBlock(Properties *props);
extern void addAutoLift(Properties *props);
extern void addCustomItem(Properties *props);
extern void reassignOwnerShips();
extern void removeBSPModelFaces();
extern void addBullet(Properties *props);
extern void addParticle(Properties *props);
extern void addDecoration(Properties *props);
extern bool loadGameData(int slotId, char *mission);
extern void fireTriggers(char *name, int type);
extern CutsceneCamera *addCutsceneCamera(Properties *props);
extern void addEmitter(Properties *props);
extern void addWeakStructure(Properties *props);
extern void addTrap(Properties *props);
extern void addLocation(Properties *props);
extern void addDecal(Properties *props);
extern void assignTriggerLocations();
extern void addSupplyCrate(Properties *props);
extern void addBoss(Properties *props);
extern void loadCutscene(char *filename, List *data);
extern void loadBossDefinition(char *filename);

extern Audio *audio;
extern BSP *bsp;
extern EntityManager *entityManager;
extern Engine *engine;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern ModelManager *modelManager;
extern RandomNameGenerator *randomNameGenerator;
extern TextureManager *textureManager;

extern Unit *player;
